==> bucket4j-jcache-4.10.0-sources.jar: io/github/bucket4j/grid/jcache/InitStateProcessor.java <==
/*-
 * ========================LICENSE_START=================================
 * Bucket4j
 * %%
 * Copyright (C) 2015 - 2020 Vladimir Bukhtoyarov
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * =========================LICENSE_END==================================
 */

package io.github.bucket4j.grid.jcache;

import io.github.bucket4j.BucketConfiguration;
import io.github.bucket4j.BucketState;
import io.github.bucket4j.Nothing;
import io.github.bucket4j.grid.CommandResult;
import io.github.bucket4j.grid.GridBucketState;
import io.github.bucket4j.serialization.DeserializationAdapter;
import io.github.bucket4j.serialization.SerializationAdapter;
import io.github.bucket4j.serialization.SerializationHandle;

import javax.cache.processor.MutableEntry;
import java.io.IOException;
import java.io.Serializable;

public class InitStateProcessor<K extends Serializable> implements JCacheEntryProcessor<K, Nothing> {

    private static final long serialVersionUID = 1;

    private BucketConfiguration configuration;

    public InitStateProcessor(BucketConfiguration configuration) {
        this.configuration = configuration;
    }

    public static SerializationHandle<InitStateProcessor<?>> SERIALIZATION_HANDLE = new SerializationHandle<InitStateProcessor<?>>() {
        @Override
        public <S> InitStateProcessor<?> deserialize(DeserializationAdapter<S> adapter, S input) throws IOException {
            BucketConfiguration configuration = (BucketConfiguration) adapter.readObject(input, BucketConfiguration.class);
            return new InitStateProcessor<>(configuration);
        }

        @Override
        public <O> void serialize(SerializationAdapter<O> adapter, O output, InitStateProcessor<?> processor) throws IOException {
            adapter.writeObject(output, processor.configuration);
        }

        @Override
        public int getTypeId() {
            return 18;
        }

        @Override
        public Class<InitStateProcessor<?>> getSerializedType() {
            return (Class) InitStateProcessor.class;
        }

    };

    @Override
    public CommandResult<Nothing> process(MutableEntry<K, GridBucketState> mutableEntry, Object... arguments) {
        if (mutableEntry.exists()) {
            return CommandResult.success(null);
        }
        long currentTimeNanos = currentTimeNanos();
        BucketState bucketState = BucketState.createInitialState(configuration, currentTimeNanos);
        GridBucketState gridBucketState = new GridBucketState(configuration, bucketState);
        mutableEntry.setValue(gridBucketState);
        return CommandResult.success(null);
    }

    public BucketConfiguration getConfiguration() {
        return configuration;
    }

}

==> bucket4j-jcache-6.4.1-sources.jar: io/github/bucket4j/grid/jcache/InitStateProcessor.java <==
/*-
 * ========================LICENSE_START=================================
 * Bucket4j
 * %%
 * Copyright (C) 2015 - 2020 Vladimir Bukhtoyarov
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * =========================LICENSE_END==================================
 */

package io.github.bucket4j.grid.jcache;

import io.github.bucket4j.BucketConfiguration;
import io.github.bucket4j.BucketState;
import io.github.bucket4j.Nothing;
import io.github.bucket4j.grid.CommandResult;
import io.github.bucket4j.grid.GridBucketState;
import io.github.bucket4j.serialization.DeserializationAdapter;
import io.github.bucket4j.serialization.SerializationAdapter;
import io.github.bucket4j.serialization.SerializationHandle;

import javax.cache.processor.MutableEntry;
import java.io.IOException;
import java.io.Serializable;

public class InitStateProcessor<K extends Serializable> implements JCacheEntryProcessor<K, Nothing> {

    private static final long serialVersionUID = 1;

    private BucketConfiguration configuration;

    public InitStateProcessor(BucketConfiguration configuration) {
        this.configuration = configuration;
    }

    public static final SerializationHandle<InitStateProcessor<?>> SERIALIZATION_HANDLE = new SerializationHandle<InitStateProcessor<?>>() {
        @Override
        public <S> InitStateProcessor<?> deserialize(DeserializationAdapter<S> adapter, S input) throws IOException {
            BucketConfiguration configuration = adapter.readObject(input, BucketConfiguration.class);
            return new InitStateProcessor<>(configuration);
        }

        @Override
        public <O> void serialize(SerializationAdapter<O> adapter, O output, InitStateProcessor<?> processor) throws IOException {
            adapter.writeObject(output, processor.configuration);
        }

        @Override
        public int getTypeId() {
            return 18;
        }

        @Override
        public Class<InitStateProcessor<?>> getSerializedType() {
            return (Class) InitStateProcessor.class;
        }

    };

    @Override
    public CommandResult<Nothing> process(MutableEntry<K, GridBucketState> mutableEntry, Object... arguments) {
        if (mutableEntry.exists()) {
            return CommandResult.success(null);
        }
        long currentTimeNanos = currentTimeNanos();
        BucketState bucketState = BucketState.createInitialState(configuration, currentTimeNanos);
        GridBucketState gridBucketState = new GridBucketState(configuration, bucketState);
        mutableEntry.setValue(gridBucketState);
        return CommandResult.success(null);
    }

    public BucketConfiguration getConfiguration() {
        return configuration;
    }

}
